Getting Involved
================

We are working hard to make coala reality. If you want to help us you
can do the following things:

-  Join us on our mailing list.
-  coala developer list:
   https://groups.google.com/forum/#!forum/coala-devel

   -  coala-devel@googlegroups.com

-  coala announcement list:
   https://groups.google.com/forum/#!forum/coala-announcements

   -  coala-announcements@googlegroups.com

-  Join us on our developer chatroom:
   https://gitter.im/coala-analyzer/coala
-  Run our tests. Just follow the instructions on the
   :doc:`Testing <../Getting_Involved/Testing>` page. Report back to us if
   anything goes wrong unexpectedly.
-  Give us feedback. If you think we're doing something useless or
   useful with some specific things, please write us! We are interested
   in your needs and favors so you get the highest possible quality.
-  Drive bug discussions. Just state your opinion, everywhere!
-  Review code. Get a glance at what we're doing and say something if
   you don't understand something or think we're doing something wrong.
-  Write documentation. If you need some additional information for
   documenting feel free to ask us!
-  Write code. Usually code we need is indicated through bug reports.
   Please get in contact with us so we can coordinate coding together.

Please take a look at the other files in this directory for getting
started with specific parts of coala.

We appreciate any help. (Partially with words, partially with chocolate
if you live near hamburg.)

Modularity, clean good code as well as a high usability for both users
and developers of analyse routines (called bears) stand in the
foreground of the development. We will not speed up our development if
it needs sacrificing any aspect of quality.
